Change log
==========

v2021.1.28
----------
* Fix SNAP stress components
* Fix unexpected test outcome in BOWSR and symbolic regression

v2021.12.13
-----------
* Update dependencies
* Fix bugs

v2021.10.13
-----------
* add bowsr

v2021.3.2
---------
* Set up namespace package architecture for maml.apps. The RFXAS package is now available as a separate package
  `maml-apps.rfxas`. Usage remains similar.

v2021.2.27
----------
* maml is now compatible with both mlip-2 and mlip-dev

v0.0.4
------
* bug fix
* compatibility with new n2p2 and mlip software
* upgrade rfxas

v0.0.3
------
* bug fix
* add atomsets models

v0.0.2
------
* major refactor
* move mlearn potential energy surfaces to apps
* fix potential problem of rotated structure in lammps
* add rfxas app
* add initial symbolic regression app
* add megnet-based describers

v0.0.1
------
* initial release
